import { Api } from '../../Api';
import { LocalStorageService } from '../LocalStorageService';
import { nameof } from 'ts-simple-nameof';
import { LoggerService } from '../Logging/LoggerService';
var WebApiCacheService = (function () {
    function WebApiCacheService() {
        this._log = Api.Get(LoggerService);
        this._serviceName = nameof(LocalStorageService);
    }
    WebApiCacheService.prototype.GetServiceName = function () {
        return this._serviceName;
    };
    WebApiCacheService.prototype.GetResourceName = function (data) {
        return "".concat(data.Resource, "_").concat(data.Method);
    };
    WebApiCacheService.prototype.Cache = function (data) {
        var tmp = JSON.stringify(data);
        this._log.Debug("Caching request: ".concat(data.Resource, " ").concat(data.Method, "\n").concat(tmp));
        WebApiCacheService._localStorageService.Save(WebApiCacheService, this.GetResourceName(data), tmp);
    };
    WebApiCacheService.prototype.GetCache = function (data) {
        var tmp = WebApiCacheService._localStorageService.Read(WebApiCacheService, this.GetResourceName(data));
        if (tmp == null)
            this._log.Debug("Got request response from cache: ".concat(data.Resource, " ").concat(data.Method, "\n").concat(tmp));
        return tmp;
    };
    WebApiCacheService.prototype.ClearCache = function () {
        WebApiCacheService._localStorageService.DropStorage(WebApiCacheService);
        this._log.Debug("Clearing cache for ".concat(this.GetServiceName()));
    };
    WebApiCacheService.prototype.Remove = function (data) {
        WebApiCacheService._localStorageService.Remove(WebApiCacheService, this.GetResourceName(data));
        this._log.Debug("Clearing cache for cache: ".concat(data.Resource, " ").concat(data.Method));
    };
    WebApiCacheService._localStorageService = Api.Get(LocalStorageService);
    return WebApiCacheService;
}());
export { WebApiCacheService };
//# sourceMappingURL=WebApiCacheService.js.map